@@ -163,9 +163,13 @@ class DataForm(QtGui.QMainWindow):
                 now = datetime.now().strftime(settings.DATA_TIME_FORMAT)
                 self.datas.append(TrafficLogLine(now, download, upload))
             else:
-                QtGui.QMessageBox.about(self, 'Problem', "Your N900 " \
-                    "isn't currently probably compatible with NetStory " \
-                    "(only PR1.2 is tested)")
+                QtGui.QMessageBox.about(self, 'Unable to read latest '\
+                    'counters', \
+                    'If you just cleared the home network data counter, '\
+                    'situation will be fixed when your phone downloads '\
+                    'something. Or the reason could be that your N900 '\
+                    'isn\'t currently compatible with NetStory '\
+                    '(tested only with PR1.2).')
         except NameError, e:
             print 'Windows testing: %s' % str(e)
             
